@@ -3,6 +3,7 @@
 
 #' @param prec matrix or data.frame containing the original precipitation data. Each column represents one station. The names of columns have to be names of the stations.
 #' @param sts matrix or data.frame. A column "ID" (unique ID of stations) is required. The rest of the columns (all of them) will act as predictors of the model.
+#' @param model_fun function. A function that integrates the statistical hybrid model (classification and regression).
 #' @param crs character. Coordinates system in EPSG format (e.g.: "EPSG:4326").
 #' @param coords vector of two character elements. Names of the fields in "sts" containing longitude and latitude.
 #' @param coords_as_preds logical. If TRUE (default), "coords" are also taken as predictors.
@@ -16,7 +17,7 @@
 #' @noRd
   
 
-qcLast <- function(x, y, sts, neibs, coords, crs, coords_as_preds = TRUE, qc = 'all', qc3 = 10, qc4 = c(0.99, 5), qc5 = c(0.01, 0.1, 5), thres = NA) {
+qcLast <- function(x, y, sts, model_fun, neibs, coords, crs, coords_as_preds = TRUE, qc = 'all', qc3 = 10, qc4 = c(0.99, 5), qc5 = c(0.01, 0.1, 5), thres = NA) {
   
   pb <- p <- NA
   
@@ -27,7 +28,8 @@ qcLast <- function(x, y, sts, neibs, coords, crs, coords_as_preds = TRUE, qc = '
   
   n <- names(sts)
   if(!coords_as_preds) n <- n[-match(coords,names(sts))]
-  covars <- paste(n, collapse='+') # predictors
+  # covars <- paste(n, collapse='+') # predictors
+  covars <- n
   
   if(length(qc)==1){
     if(qc == "all") qc <- as.character(paste0(1:5))
@@ -46,9 +48,9 @@ qcLast <- function(x, y, sts, neibs, coords, crs, coords_as_preds = TRUE, qc = '
     
     #subset dataset based on available data
     cle <- data.frame(sts[wx,],val = x[wx])
-    cle <- vect(cle, geom = coords,crs = crs, keepgeom = TRUE)
+    cle <- terra::vect(cle, geom = coords,crs = crs, keepgeom = TRUE)
     ori <- data.frame(sts[wy,],val = y[wy])
-    ori <- vect(ori, geom = coords,crs = crs, keepgeom = TRUE)
+    ori <- terra::vect(ori, geom = coords,crs = crs, keepgeom = TRUE)
     
     
     if (max(y, na.rm = T) == 0) {
@@ -60,11 +62,11 @@ qcLast <- function(x, y, sts, neibs, coords, crs, coords_as_preds = TRUE, qc = '
         for (h in 1:length(ori)) {
           can <- ori[h,]
           # checks if candidate is within reference
-          ws <- which(relate(can, cle, "intersects"))
+          ws <- which(terra::relate(can, cle, "intersects"))
           # if it is, pull it out
           if(length(ws)>0) ref <- cle[-ws] else ref <- cle
           # cleaned data act as neighboring observations
-          dd <- distance(can,ref)/1000
+          dd <- terra::distance(can,ref)/1000
           if(!is.na(thres)){ 
             dd <- dd[dd<thres]
           }
@@ -88,33 +90,12 @@ qcLast <- function(x, y, sts, neibs, coords, crs, coords_as_preds = TRUE, qc = '
               pb <- 1
               p <- ref$val[1]
             } else{
-                # probability of ocurrence prediction
-                rr <- as.data.frame(ref)
-                rr$val[rr$val > 0] <- 1
-                
-                
-                f <- as.formula(paste0('val ~ ',covars))
-                fmtb <- suppressWarnings(
-                  glm(f,family = binomial(),data = rr)
-                )
-                
-                pb <- round(predict(fmtb, newdata = as.data.frame(can), 
-                                    type = "response"),3)
-                
-                #amount prediction
-                #rescaling
-                rr <- as.data.frame(ref)
-                MINc <- min(rr$val) - (as.numeric(quantile(rr$val, 0.50)) - as.numeric(quantile(rr$val, 0.25)))
-                MINc <- ifelse(MINc<0,0,MINc)
-                MAXc <- max(rr$val) + (as.numeric(quantile(rr$val, 0.75))-as.numeric(quantile(rr$val, 0.50)))
-                RANGE <- as.numeric(MAXc - MINc)
-                rr$val <- (rr$val - MINc) / RANGE
-                
-                fmt <- suppressWarnings(
-                  glm(f,family = quasibinomial(),data = rr)
-                )
-                p <- predict(fmt, newdata = as.data.frame(can),type = "response")
-                p <- round((p * RANGE) + MINc, 3)
+              
+              out <- model_fun(ref = ref, can = can, covars = covars)
+              out <- round(out, 3)
+              pb <- out[1]
+              p <- out[2]
+              
               }
             }
           }
